@@ -57,14 +57,25 @@ class JobBase(abc.ABC):
 
     @property
     def home_directory(self):
-        """Directory that is used to store files, e.g. generated images"""
+        """
+        Directory that is used to store files (e.g. generated images) or empty
+        string
+
+        This directory is guaranteed to exist.
+        """
+        if self._home_directory and not os.path.exists(self._home_directory):
+            fs.mkdir(self._home_directory)
         return self._home_directory
 
     @cached_property
     def cache_directory(self):
-        """Path to existing directory that stores :attr:`cache_file`"""
+        """
+        Path to existing directory that stores :attr:`cache_file`
+
+        This directory is guaranteed to exist.
+        """
         if not os.path.exists(self._cache_directory):
-            os.makedirs(self._cache_directory)
+            fs.mkdir(self._cache_directory)
         return self._cache_directory
 
     @property
@@ -103,7 +114,7 @@ class JobBase(abc.ABC):
     @property
     def is_enabled(self):
         """
-        Return value of `condition` as :class:`bool`
+        Return value of :attr:`condition` as :class:`bool`
 
         If this value is `False`, this job must not be started nor included in
         the UI.
@@ -154,7 +165,7 @@ class JobBase(abc.ABC):
     def __init__(self, *, home_directory=None, cache_directory=None,
                  ignore_cache=False, hidden=False, autostart=True,
                  condition=None, callbacks={}, **kwargs):
-        self._home_directory = home_directory if home_directory else '.'
+        self._home_directory = home_directory if home_directory else ''
         self._cache_directory = cache_directory if cache_directory else constants.CACHE_DIRPATH
         self._ignore_cache = bool(ignore_cache)
         self._hidden = bool(hidden)
@@ -338,17 +349,16 @@ class JobBase(abc.ABC):
         if not self.is_finished:
             self._warnings.clear()
 
-    def error(self, error, finish=False):
+    def error(self, error):
         """
-        Append `error` to :attr:`errors` and emit ``error`` signal
+        Append `error` to :attr:`errors`, emit ``error`` signal and :meth:`finish`
+        this job
 
-        :param bool finish: Whether to call :meth:`finish` after handling
-            `error`
+        Do nothing if this job is already finished.
         """
         if not self.is_finished:
-            if finish:
-                self.finish()
             self.signal.emit('error', error)
+            self.finish()
 
     @property
     def errors(self):
