@@ -49,7 +49,7 @@ class SceneSearchJob(JobBase):
         try:
             query = scene.SceneQuery.from_string(self._content_path)
         except errors.SceneError as e:
-            self.error(e, finish=True)
+            self.error(e)
         else:
             self._search_task = asyncio.ensure_future(
                 scene.search(query=query),
@@ -59,7 +59,7 @@ class SceneSearchJob(JobBase):
     def _handle_results(self, task):
         try:
             results = task.result()
-        except errors.SceneError as e:
+        except (errors.RequestError, errors.SceneError) as e:
             self.error(e)
         else:
             _log.debug('Handling results: %r', results)
@@ -133,9 +133,10 @@ class SceneCheckJob(JobBase):
         try:
             return await coro
         except errors.RequestError as e:
-            self.error(e, finish=True)
+            self.warn(e)
+            self.signal.emit('ask_is_scene_release', types.SceneCheckResult.unknown)
         except errors.SceneError as e:
-            self.error(e, finish=True)
+            self.error(e)
         except BaseException as e:
             self.exception(e)
 
@@ -151,7 +152,7 @@ class SceneCheckJob(JobBase):
         is_scene_release = await scene.is_scene_release(self._content_path)
         if is_scene_release is types.SceneCheckResult.false:
             _log.debug('Not a scene release: %r', self._content_path)
-            self._handle_scene_check_result(types.SceneCheckResult.false, exceptions=())
+            self._handle_scene_check_result(types.SceneCheckResult.false)
         else:
             # Find specific release name. If there are multiple search results,
             # ask the user to pick one.
@@ -159,11 +160,13 @@ class SceneCheckJob(JobBase):
             results = await scene.search(query, only_existing_releases=False)
             if not results:
                 _log.debug('No search results: %r', self._content_path)
-                self._handle_scene_check_result(types.SceneCheckResult.unknown, exceptions=())
+                self._handle_scene_check_result(types.SceneCheckResult.unknown)
+
             # Autopick if release name is in search results
             elif self._release_name in results:
                 _log.debug('Autopicking from search results: %r', self._release_name)
                 await self._verify_release(self._release_name)
+
             # Autopick single result if we know it's a scene release. If there
             # is missing information (e.g. no group), is_scene_release() returns
             # SceneCheckResult.unknown and we ask the user.
@@ -171,6 +174,7 @@ class SceneCheckJob(JobBase):
                 release_name = results[0]
                 _log.debug('Autopicking only search result: %r', release_name)
                 await self._verify_release(release_name)
+
             else:
                 _log.debug('Asking for release name: %r', results)
                 self.signal.emit('ask_release_name', results)
@@ -191,7 +195,7 @@ class SceneCheckJob(JobBase):
                 )
             )
         else:
-            self._handle_scene_check_result(types.SceneCheckResult.false, exceptions=())
+            self._handle_scene_check_result(types.SceneCheckResult.false)
 
     async def _verify_release(self, release_name):
         _log.debug('Verifying release: %r', release_name)
@@ -201,16 +205,14 @@ class SceneCheckJob(JobBase):
     def _handle_scene_check_result(self, is_scene_release, exceptions=()):
         _log.debug('Handling result: %r: %r', is_scene_release, exceptions)
 
-        # Split exceptions into errors and warnings
-        serious_errors = [e for e in exceptions if not isinstance(e, errors.SceneMissingInfoError)]
         warnings = [e for e in exceptions if isinstance(e, errors.SceneMissingInfoError)]
-        for e in serious_errors:
-            self.error(e)
-            if hasattr(e, 'url') and e.url:
-                self.error(e.url)
         for e in warnings:
             self.warn(e)
 
+        serious_errors = [e for e in exceptions if not isinstance(e, errors.SceneMissingInfoError)]
+        for e in serious_errors:
+            self.error(e)
+
         if serious_errors:
             self.finish()
         elif is_scene_release in (types.SceneCheckResult.true, types.SceneCheckResult.false):
