@@ -1,5 +1,5 @@
 """
-BhdTrackerConfig class
+Concrete :class:`~.base.TrackerConfigBase` subclass for BHD
 """
 
 import base64
@@ -16,6 +16,7 @@ class BhdTrackerConfig(TrackerConfigBase):
         'apikey'           : '',
         'source'           : 'BHD',
         'anonymous'        : types.Bool('no'),
+        'draft'            : types.Bool('no'),
         'image_host'       : 'imgbox',
         'exclude'          : [
             r'\.(?i:nfo|txt|jpg|jpeg|png|sfv|md5)$',
