@@ -108,9 +108,11 @@ class submit(CommandBase):
     def _get_imghost(self):
         imghost_name = self.tracker_options.get('image_host', None)
         if imghost_name:
+            imghost_config = self.config['imghosts'][imghost_name].copy()
+            imghost_config.update(self.tracker.TrackerJobs.image_host_config.get(imghost_name, {}))
             return utils.imghosts.imghost(
                 name=imghost_name,
-                **self.config['imghosts'][imghost_name],
+                **imghost_config,
             )
 
     def _get_btclient(self):
