@@ -5,6 +5,7 @@ Custom TUI widgets
 import collections
 import textwrap
 
+from prompt_toolkit.application import get_app
 from prompt_toolkit.buffer import Buffer
 from prompt_toolkit.document import Document
 from prompt_toolkit.filters import Condition
@@ -16,6 +17,8 @@ from prompt_toolkit.layout.controls import BufferControl, FormattedTextControl
 from prompt_toolkit.layout.dimension import Dimension
 from prompt_toolkit.utils import get_cwidth
 
+from . import utils
+
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
@@ -31,6 +34,7 @@ class TextField:
         self._text = text
         self._width = width
         self._height = height
+        self._throbber = utils.Throbber(callback=self.set_text)
         self.container = Window(
             content=FormattedTextControl(lambda: self.text),
             width=width,
@@ -47,6 +51,9 @@ class TextField:
 
     @text.setter
     def text(self, text):
+        self.set_text(text)
+
+    def set_text(self, text):
         if isinstance(self._width, int) and self._width > 1:
             width = self._width
             if isinstance(self._height, int):
@@ -64,6 +71,16 @@ class TextField:
             ) for paragraph in paragraphs)
         else:
             self._text = text
+        get_app().invalidate()
+
+    @property
+    def is_loading(self):
+        """Whether an activity indicator is displayed"""
+        return self._throbber.active
+
+    @is_loading.setter
+    def is_loading(self, is_loading):
+        self._throbber.active = is_loading
 
     def __pt_container__(self):
         return self.container
@@ -74,6 +91,7 @@ class InputField:
 
     def __init__(self, text='', width=None, extend_width=True, read_only=False,
                  on_accepted=None, on_changed=None, style=''):
+        self._throbber = utils.Throbber(callback=self.set_text, interval=0.1)
         self.read_only = read_only
         self.on_accepted = on_accepted
         self.buffer = Buffer(
@@ -105,15 +123,19 @@ class InputField:
 
     @text.setter
     def text(self, text):
-        self.buffer.set_document(Document(text), bypass_readonly=True)
+        self.set_text(text)
 
-    def set_text(self, text, ignore_callback=False):
+    def set_text(self, text, ignore_callback=False, preserve_cursor_position=True):
+        if preserve_cursor_position:
+            curpos = self.buffer.cursor_position
         if ignore_callback:
             handlers = self.buffer.on_text_changed._handlers
             self.buffer.on_text_changed._handlers = []
         self.buffer.set_document(Document(text), bypass_readonly=True)
         if ignore_callback:
             self.buffer.on_text_changed._handlers = handlers
+        if preserve_cursor_position:
+            self.buffer.cursor_position = curpos
 
     @property
     def read_only(self):
@@ -123,6 +145,15 @@ class InputField:
     def read_only(self, read_only):
         self._read_only = bool(read_only)
 
+    @property
+    def is_loading(self):
+        """Whether an activity indicator is displayed"""
+        return self._throbber.active
+
+    @is_loading.setter
+    def is_loading(self, is_loading):
+        self._throbber.active = is_loading
+
     def __pt_container__(self):
         return self.container
 
