@@ -266,6 +266,9 @@ class ReleaseName(collections.abc.Mapping):
         """List of "DC", "Uncut", "Unrated", etc"""
         if 'edition' not in self._info:
             self._info['edition'] = []
+        if 'Dual Audio' not in self._info['edition']:
+            if self.has_dual_audio:
+                self._info['edition'].append('Dual Audio')
         return self._info['edition']
 
     @edition.setter
@@ -376,6 +379,39 @@ class ReleaseName(collections.abc.Mapping):
         else:
             self._has_commentary = bool(value)
 
+    @property
+    def has_dual_audio(self):
+        """
+        Whether this release has an English and a non-English, original language
+        audio track
+
+        If not set explicitly and the given `path` exists, this value is
+        autodetected if possible, otherwise default to whatever
+        :class:`ReleaseInfo` detected in the release name.
+
+        Setting this value back to `None` turns on autodetection as described
+        above.
+        """
+        # Use manually set value unless it is None
+        if hasattr(self, '_has_dual_audio') and self._has_dual_audio is not None:
+            return self._has_dual_audio
+
+        # Autodetect dual audio
+        elif os.path.exists(self._path):
+            self._has_dual_audio = bool(video.has_dual_audio(self._path))
+            return self._has_dual_audio
+
+        # Default to ReleaseInfo['has_dual_audio']
+        else:
+            return 'Dual Audio' in self._info.get('edition', ())
+
+    @has_dual_audio.setter
+    def has_dual_audio(self, value):
+        if value is None:
+            self._has_dual_audio = value
+        else:
+            self._has_dual_audio = bool(value)
+
     _needed_attrs = {
         ReleaseType.movie: ('title', 'year', 'resolution', 'source',
                             'audio_format', 'video_format'),
@@ -737,6 +773,10 @@ class ReleaseInfo(collections.abc.MutableMapping):
         guessit_other = _as_list(self._guess.get('other'))
         if 'Dual Audio' in guessit_other:
             edition.append('Dual Audio')
+        if 'Open Matte' in guessit_other:
+            edition.append('Open Matte')
+        if 'Original Aspect Ratio' in guessit_other:
+            edition.append('OAR')
 
         return edition
 
@@ -746,6 +786,8 @@ class ReleaseInfo(collections.abc.MutableMapping):
     _streaming_service_regex = re.compile(r'[ \.]([A-Z]+)[ \.](?i:WEB-?(?:DL|Rip))(?:[ \.]|$)')
     _streaming_service_translation = {
         re.compile(r'(?i:IT)') : 'iT',
+        # Not a streaming service
+        re.compile(r'OAR') : '',  # Original Aspect Ratio
     }
 
     def _get_service(self):
@@ -774,7 +816,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
         # Default to manual detection
         match = self._streaming_service_regex.search(self.release_name_params)
         if match:
-            return match.group(1)
+            return translate(match.group(1))
 
         return ''
 
