@@ -5,6 +5,8 @@ Abstract base class for online databases
 import abc
 import asyncio
 
+from .common import Query
+
 
 class WebDbApiBase(abc.ABC):
     """
@@ -24,6 +26,17 @@ class WebDbApiBase(abc.ABC):
     def label(self):
         """User-facing name of this DB"""
 
+    def sanitize_query(self, query):
+        """
+        Modify :class:`~.common.Query` for specific DB
+
+        See :meth:`.TvmazeApi.sanitize_query` for an example.
+        """
+        if not isinstance(query, Query):
+            raise TypeError(f'Not a Query instance: {query!r}')
+        else:
+            return query
+
     @abc.abstractmethod
     async def search(self, query):
         """
@@ -51,8 +64,8 @@ class WebDbApiBase(abc.ABC):
         """Return list of director names (usually empty for series)"""
 
     @abc.abstractmethod
-    async def keywords(self, id):
-        """Return list of keywords, e.g. genres"""
+    async def genres(self, id):
+        """Return list of genres"""
 
     @abc.abstractmethod
     async def poster_url(self, id):
