@@ -27,31 +27,42 @@ class TvmazeApi(WebDbApiBase):
         super().__init__(*args, **kwargs)
         self._imdb = ImdbApi()
 
+    def sanitize_query(self, query):
+        """Set :attr:`~.common.Query.type` to :attr:`~.types.ReleaseType.unknown`"""
+        query = super().sanitize_query(query)
+        query.type = ReleaseType.unknown
+        return query
+
     async def search(self, query):
         _log.debug('Searching TVmaze for %s', query)
-        if not query.title or query.type is ReleaseType.movie:
+
+        if query.id:
+            show = await self._get_show(query.id)
+            return [_TvmazeSearchResult(show=show, tvmaze_api=self)]
+
+        elif not query.title or query.type is ReleaseType.movie:
             return []
 
-        url = f'{self._url_base}/search/shows'
-        params = {'q': query.title_normalized}
-
-        results_str = await http.get(url, params=params, cache=True)
-        try:
-            items = json.loads(results_str)
-            assert isinstance(items, list)
-        except (ValueError, TypeError, AssertionError):
-            raise errors.RequestError(f'Unexpected search response: {results_str}')
         else:
-            results = [_TvmazeSearchResult(show=item['show'], tvmaze_api=self)
-                       for item in items]
-            # The API doesn't allow us to search for a specific year
-            if query.year:
-                results_in_year = []
-                for result in results:
-                    if str(result.year) == query.year:
-                        results_in_year.append(result)
-                return results_in_year
-            return results
+            url = f'{self._url_base}/search/shows'
+            params = {'q': query.title_normalized}
+            results_str = await http.get(url, params=params, cache=True)
+            try:
+                items = json.loads(results_str)
+                assert isinstance(items, list)
+            except (ValueError, TypeError, AssertionError):
+                raise errors.RequestError(f'Unexpected search response: {results_str}')
+            else:
+                results = [_TvmazeSearchResult(show=item['show'], tvmaze_api=self)
+                           for item in items]
+                # The API doesn't allow us to search for a specific year
+                if query.year:
+                    results_in_year = []
+                    for result in results:
+                        if str(result.year) == query.year:
+                            results_in_year.append(result)
+                    return results_in_year
+                return results
 
     async def _get_json(self, url):
         response = await http.get(url, cache=True)
@@ -94,9 +105,9 @@ class TvmazeApi(WebDbApiBase):
     async def directors(self, id):
         return ()
 
-    async def keywords(self, id):
+    async def genres(self, id):
         show = await self._get_show(id)
-        return _get_keywords(show)
+        return _get_genres(show)
 
     async def poster_url(self, id, season=None):
         """
@@ -198,18 +209,18 @@ class TvmazeApi(WebDbApiBase):
 class _TvmazeSearchResult(common.SearchResult):
     def __init__(self, *, show, tvmaze_api):
         return super().__init__(
+            cast=functools.partial(tvmaze_api.cast, show['id']),
+            countries=_get_countries(show),
+            directors=(),
+            genres=_get_genres(show),
             id=show['id'],
+            summary=_get_summary(show),
             title=show['name'],
+            title_english=functools.partial(tvmaze_api.title_english, show['id']),
+            title_original=functools.partial(tvmaze_api.title_original, show['id']),
             type=ReleaseType.series,
             url=show['url'],
             year=_get_year(show),
-            cast=functools.partial(tvmaze_api.cast, show['id']),
-            countries=_get_countries(show),
-            director='',
-            keywords=_get_keywords(show),
-            summary=_get_summary(show),
-            title_english=functools.partial(tvmaze_api.title_english, show['id']),
-            title_original=functools.partial(tvmaze_api.title_original, show['id']),
         )
 
 
@@ -230,7 +241,7 @@ def _get_year(show):
     else:
         return ''
 
-def _get_keywords(show):
+def _get_genres(show):
     genres = show.get('genres', None)
     if genres:
         return tuple(str(g).lower() for g in genres)
